"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getModifiedLines = getModifiedLines;
const {
  Logger
} = require("../../utils/logger");

/**
 * @function getModifiedLines - This Methods use to get impact lines from git diff
 * @param {string} content - impacted lines and code as string get from git diff
 * @returns {Object}
 */

function getModifiedLines(content) {
  let diffLinesArr = [];
  let removedLines = [];
  try {
    let diffLineContentIter = content.split("\n");
    let addLineFrom = -1;
    let removeLineFrom = -1;
    let affectedLineNum = 0;
    let addedLineSubtractor = 0;
    let isRemovedLineAdded = false;
    let tempDiffLinesArr = new Set();
    let removedContent = "";
    let addedContent = "";
    for (let currentDiffLine of diffLineContentIter) {
      if (addLineFrom !== -1 && removeLineFrom !== -1 && currentDiffLine || currentDiffLine.startsWith("@")) {
        if (currentDiffLine.startsWith("@")) {
          isRemovedLineAdded = false;
          if (tempDiffLinesArr.size > 0 && addedContent !== removedContent) {
            tempDiffLinesArr.forEach(line => diffLinesArr.push(line));
          }
          if (removedContent && !addedContent) {
            tempDiffLinesArr.forEach(line => removedLines.push(line));
          }
          removedContent = "";
          addedContent = "";
          tempDiffLinesArr.clear();
          let lineNos = currentDiffLine.split("@@")[1].trim().split(" ");
          let removedLineDetail = lineNos[0].replace(/-/g, "").split(",");
          let addedLineDetail = lineNos[1].replace(/\+/g, "").split(",");
          addLineFrom = parseInt(addedLineDetail[0]);
          removeLineFrom = parseInt(removedLineDetail[0]) + addedLineSubtractor;
          affectedLineNum = removedLineDetail.length > 1 && parseInt(removedLineDetail[1]) > 0 ? removeLineFrom : addLineFrom;
        } else {
          let isLineChanged = (currentDiffLine.startsWith("+") || currentDiffLine.startsWith("-") && !isRemovedLineAdded) && currentDiffLine.trim().length > 1;
          let currentDiffContent = currentDiffLine.substring(1).trim();
          if (currentDiffLine.startsWith("-")) {
            addedLineSubtractor--;
            removedContent += currentDiffContent;
          } else if (currentDiffLine.startsWith("+")) {
            addedLineSubtractor++;
            addedContent += currentDiffContent;
          }
          if (isLineChanged) {
            tempDiffLinesArr.add(affectedLineNum);
          }
          if (!currentDiffLine.startsWith("-")) {
            affectedLineNum++;
          }
          isRemovedLineAdded = !isRemovedLineAdded && currentDiffLine.startsWith("-") && currentDiffLine.trim().length > 1 || isRemovedLineAdded && currentDiffLine.startsWith("-");
        }
      }
    }
    if (tempDiffLinesArr.size > 0 && addedContent !== removedContent) {
      tempDiffLinesArr.forEach(line => diffLinesArr.push(line));
      if (removedContent && !addedContent) {
        tempDiffLinesArr.forEach(line => removedLines.push(line));
      }
    }
  } catch (exp) {
    Logger.log(Logger.FAILURE_TYPE, `Exception Occurred:${exp}`);
  }
  return {
    modifiedLines: diffLinesArr,
    removedLines: removedLines
  };
}