"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _Eslint = _interopRequireDefault(require("../core/handlers/libraryInterface/Eslint"));
var _Execution = _interopRequireDefault(require("../core/handlers/libraryInterface/Execution"));
var _SonarQube = _interopRequireDefault(require("../core/handlers/libraryInterface/SonarQube"));
var _initialSetup = require("../setup/initialSetup");
var _cliArgsToObject = require("../utils/cliArgsToObject");
// import { executeLintAnalysis } from "../lint/eslint/runEslint";
// import { executeSonarAnalysis } from "../lint/sonar-dependencies/runSonar";

/**
 *
 * @function startLinterAnalysis
 * @description -  this function start linter analysis process and initial setup
 * @return {Promise<void>}
 */

async function startLinterAnalysis() {
  global.analytics = {
    reportStatus: true,
    pipelineStatus: 'passed',
    sonarQubeStatus: true
  };
  const [,, action, ...option] = process.argv;
  switch (action) {
    case "lint":
      {
        const $cliObjects = (0, _cliArgsToObject.cliArgsToObject)(option);
        $cliObjects.env = 'dev';
        const execute = new _Execution.default(_Eslint.default, _SonarQube.default, $cliObjects);
        await execute.executeLintHandler().finally(() => {
          execute.executeMetricHandler();
        });
        break;
      }
    case "lint-ci":
      {
        const $cliObjects = (0, _cliArgsToObject.cliArgsToObject)(option);
        $cliObjects.env = 'ci';
        const execute = new _Execution.default(_Eslint.default, _SonarQube.default, $cliObjects);
        await execute.executeLintHandler().finally(() => {
          execute.executeMetricHandler();
        });
        break;
      }
    case "init":
      {
        // const $cliObjects = cliArgsToObject(option)
        (0, _initialSetup.setupDefaultConfiguration)();
        break;
      }
    default:
      {
        break;
      }
  }
}
startLinterAnalysis();