"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.cliArgsToObject = cliArgsToObject;
exports.objectToCliArgs = objectToCliArgs;
/**
 * @function cliArgsToObject -  convert cli argument to object
 * @param {Array<string>} cliArgs - cli argument from enduser
 * @param {any} isKeyNeedToBeAdded - option
 * @returns {Object}
 */
function cliArgsToObject(cliArgs, isKeyNeedToBeAdded = null) {
  const processEnv = {};
  cliArgs.forEach(option => {
    if (/^--./.test(option)) {
      const equIndex = option.indexOf('=');
      let key = option.slice(2, equIndex);
      let value = option.slice(equIndex + 1);
      if (equIndex === -1) {
        key = option.slice(2);
        value = true;
      }
      processEnv[key] = value;
    }
  });
  return processEnv;
}

/**
 * @function cliArgsToObject -  convert object argument to cliArgs
 * @param {Object} objectToBeConverted - object need to convert
 * @param {any} isKeyNeedToBeAdded -  option
 * @returns {Array<string>}
 */

function objectToCliArgs(objectToBeConverted, isKeyNeedToBeAdded) {
  const argsArray = [];
  Object.keys(objectToBeConverted).forEach(key => {
    if (isKeyNeedToBeAdded(key)) {
      if (typeof objectToBeConverted[key] === 'boolean' && objectToBeConverted[key]) {
        argsArray.push(`--${key}`);
      } else {
        argsArray.push(`--${key}=${objectToBeConverted[key]}`);
      }
    }
  });
  return argsArray;
}